@@ -1,13 +1,67 @@
 package GraphViz::Traverse::Filesystem;
-our $AUTHORITY = 'cpan:GENE';
-our $VERSION = '0.0201_1';
+our $VERSION = 0.01;
 use strict;
 use warnings;
-use Carp;
 use base qw( GraphViz::Traverse );
 use File::Find;
 use File::Basename;
 
+sub node_label { return '' }
+
+sub node_height { return 0.4 }
+
+sub node_style { return 'filled' }
+
+sub node_width { return 0.4 }
+
+sub node_tooltip {
+    my $self = shift;
+    return shift;   # Just hand back the node, which is the current path.
+}
+
+sub node_peripheries {
+    # If we are executable, then we get a ring.
+    my $self = shift;
+    $_ = shift;
+    return !-d $_ && -x $_ ? 2 : 1;
+}
+
+sub node_fillcolor {
+    my $self = shift;
+    $_ = shift;
+    return
+        -d $_ ? 'snow' :
+        # perl-ish things
+        /\.pod$/ ? 'cadetblue' :
+        /\.pm$/  ? 'cadetblue4' :
+        /\.cgi$/ ? 'cadetblue3' :
+        /\.pl$/  ? 'cadetblue2' :
+        # "ordinary" files
+        /(?:readme|install|todo|faq|change|bugs)/i ? 'goldenrod' :
+        /\.conf$/      ? 'gold' :
+        /(?:\.|_)log$/ ? 'gold3' :
+        /\.txt$/       ? 'gold4' :
+        # html and friends
+        /\.css$/   ? 'plum' :
+        /\.html?$/ ? 'plum3' :
+        /\.tm?pl$/ ? 'plum4' :
+        # javascript
+        /\.js$/ ? 'salmon' :
+        # php
+        /\.php$/ ? 'seagreen' :
+        # images
+        /\.jpe?g$/ ? 'orchid4' :
+        /\.gif$/   ? 'orchid3' :
+        /\.png$/   ? 'orchid1' :
+        # archives
+        /\.tar.gz$/ ? 'red3' :
+        /\.tgz$/    ? 'red2' :
+        /\.zip$/    ? 'red1' :
+        /\.dump$/   ? 'pink' :
+#        /\.$/ ? '' :
+        'yellow';
+}
+
 sub edge_color { return 'gray' }
 
 sub traverse {
@@ -30,71 +84,24 @@ sub traverse {
 
 __END__
 
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
-GraphViz::Traverse::Filesystem
-
-=head1 VERSION
-
-version 0.0201_1
+GraphViz::Traverse::Filesystem - Graph a filesystem
 
 =head1 SYNOPSIS
 
   use GraphViz::Traverse::Filesystem;
-  $g = GraphViz::Traverse::Filesystem->new(
-      ratio => 'compress', bgcolor => 'beige'
-  );
-  $g->traverse($root);
-  print $g->as_debug;
+  my $g = GraphViz::Traverse::Filesystem->new() or die $!;
+  $g->traverse('.');
+  print $g->as_debug();
 
 =head1 DESCRIPTION
 
-B<DEPRECATED>
-
 A C<GraphViz::Traverse::Filesystem> object provides methods to traverse a
 file system and render it with C<GraphViz>.
 
 Inherit this module to define and use custom B<node_*> and B<edge_*>
-methods.  Example:
-
-  package Foo;
-  use strict;
-  use warnings;
-  use base qw( GraphViz::Traverse::Filesystem );
-  sub node_style { return 'filled' }
-  sub node_peripheries {
-    my $self = shift;
-    $_ = shift;
-    return !-d $_ && -x $_ ? 2 : 1; # Executable? Get a ring.
-  }
-  sub node_fillcolor {
-    my $self = shift;
-    $_ = shift;
-    return
-        -d $_ ? 'snow' :
-        /\.pod$/   ? 'cadetblue' :
-        /\.pm$/    ? 'cadetblue4' :
-        /\.cgi$/   ? 'cadetblue3' :
-        /\.pl$/    ? 'cadetblue2' :
-        /(?:readme|changes?)/i ? 'goldenrod' :
-        /\.txt$/   ? 'gold4' :
-        /\.css$/   ? 'plum' :
-        /\.html?$/ ? 'plum3' :
-        /\.jpe?g$/ ? 'orchid4' :
-        /\.gif$/   ? 'orchid3' :
-        /\.png$/   ? 'orchid1' :
-        /\.t(?:ar\.)?gz$/ ? 'red3' :
-        /\.zip$/   ? 'red1' :
-        /\.dump$/  ? 'pink' :
-        'yellow';
-  }
-  sub edge_color { return 'gray' }
-  # etc.
-  1;
+methods.
 
 =head1 PUBLIC METHODS
 
@@ -105,25 +112,23 @@ methods.  Example:
 Traverse a file system starting at the given root path and populate
 the C<GraphViz> object with file nodes-and path-edges.
 
-=head2 edge_color
-
-Foo
-
 =head1 SEE ALSO
 
 L<GraphViz>
 
 L<GraphViz::Traverse>
 
+=head1 COPYRIGHT
+
+Copyright 2006, Gene Boggs, All Rights Reserved
+
+=head1 LICENSE
+
+You may use this module under the license terms of the parent
+L<GraphViz> package.
+
 =head1 AUTHOR
 
-Gene Boggs <gene@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2019 by Gene Boggs.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+Gene Boggs E<lt>gene@cpan.orgE<gt>
 
 =cut
